// image.h
// abstract image class

// Copyright 2000, the Webulator (webulator@beer.com)

// Note: next_file() returns the starting address of the next file, in
// continuous byte data.  All conversions and concatenation should be
// performed either inside the argumented constructor or before returning.
//
// Note: next_file_size should be set as exactly as possible, but may be
// left as an upper bound if the exact size is not yet known.  If (and only
// if) no more files are available, next_file_size should be set to zero.
// This is only a suggestion, but it will ease the transition should the
// interface change.


#ifndef __IMAGE_H__
#define __IMAGE_H__
#include "err.h"							// return codes for all types

class CImage {
public:
	CImage();
	CImage(char *p, unsigned int size);		// sets image_raw = p and image_size = size
	virtual ~CImage();						// not pure virtual
protected:
	char *image_raw;						// file base
	char *image_end;						// for memory checks
	unsigned image_size;					// raw size
	unsigned next_file_size;				// upper bound in bytes - set to zero when no more files
	virtual reset() = 0;					// set pointers to first file
public:
	virtual char *next_file(unsigned *size) = 0;	// address of next file and actual size
	char *name;								// volume or disk name
	int error;								// set only if the image is badly formatted
};

#endif	// __IMAGE_H__
